# Changes

## v0.1.0 (2025-04-03)

### Feat

- support Django 5.2. Drop Django 5.0

### Fix

- **deps**: update dependency pydantic to >=2.11.1,<3.0.0
- **deps**: update dependency pydantic to >=2.11.0,<3.0.0
- **deps**: update dependency djangorestframework to >=3.16.0

### Refactor

- add pyupgrade / django-upgrade precommit hooks

## v0.1.0b5 (2025-03-21)

## v0.1.0b4 (2025-03-19)

### Feat

- add api router index view

### Fix

- **deps**: update dependency django-stubs-ext to >=5.1.3

## v0.1.0b3 (2025-03-19)

## v0.1.0b2 (2025-03-19)

### Feat

- add Router class for view routing by HTTP method

## v0.1.0b1 (2025-03-17)

### Feat

- add FastAPI-inspired utils for building typed views in Django

## v0.1.0b0 (2025-03-11)

### Feat

- add partition_results func
- add Result types

## v0.1.0a1 (2025-03-07)

### Feat

- add thelabtyping.drf.renderers
- add thelabtyping.abc.ListOf

## v0.1.0a0 (2025-03-07)

### Feat

- initial commit
